import React, { useEffect, useState } from 'react'
import {
  Modal,
  ModalOverlay,
  ModalContent,
  ModalHeader,
  ModalFooter,
  ModalBody,
  Button,
  Kbd,
  useToast,
  Spacer,
  Flex,
} from '@chakra-ui/react'

import DisconnectButton from './DisconnectButton'

import useStore from '../store'

const MenuOverlay: React.FC = () => {
  const [helpToastShown, setHelpToastShown] = useState<boolean>(false)
  const pointerLockControls = useStore((state) => state.pointerLockControls)
  const pointerLocked = useStore((state) => state.pointerLocked)
  const toast = useToast()

  useEffect(() => {
    if (!helpToastShown && pointerLocked) {
      toast({
        description: 'Para volver al menú, pulsá ESC',
        duration: 5000,
        isClosable: false,
      })
      setHelpToastShown(true)
    }
  }, [pointerLocked, helpToastShown])

  const lockControls = () => {
    if (pointerLockControls && !pointerLocked) {
      pointerLockControls.lock?.()
    }
  }

  return (
    <>
      <Modal isOpen={!pointerLocked} onClose={() => undefined} size="xl">
        <ModalOverlay />
        <ModalContent>
          <ModalHeader>museo.red</ModalHeader>
          <ModalBody mb="2rem" mx="2rem" textAlign="center">
            Usa las teclas <Kbd>W</Kbd>, <Kbd>A</Kbd>, <Kbd>S</Kbd> y <Kbd>D</Kbd> para
            moverte. Usá el mouse para mirar alrededor
          </ModalBody>
          <ModalFooter as={Flex}>
            <DisconnectButton colorScheme="gray" />
            <Spacer />
            <Button colorScheme="blue" onClick={lockControls} size="lg">
              Continuar
            </Button>
          </ModalFooter>
        </ModalContent>
      </Modal>
    </>
  )
}

export default MenuOverlay
